contacts : Contacts — amici1

# `contacts` : Contacts

See also `lino_amici.lib.contacts`.

## Models

## Actors

- Observed events : (no docstring)

- Civil states : (no docstring)

- Partners : (no docstring)

- Partners : (no docstring)

- Partners : (no docstring)

- Persons : (no docstring)

- Organization types : (no docstring)

- Organizations : (no docstring)

- Functions : (no docstring)

- Contact persons : (no docstring)

- Contact persons : (no docstring)

- Contact for : Shows all roles of a person.

- Child organisations : (no docstring)